==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Pla aproximat...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Aproxima un pla</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Superfície B-Spline aproximada...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation type="unfinished">Approximate surface...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Aproxima una superfície B-spline</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Reconstrucció de superfícies de Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Núvols de punts estructurats</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulació de núvols de punts estructurats</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Ajusta una superfície B-Spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>Direcció u</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Graus</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Punts de control</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>Direcció v</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Iteracions</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Factor de dimensió</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Suavitzat</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Pes total</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Longitud del degradat</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Energia de flexió</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Variació de la curvatura</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Direccions u/v definides per l'usuari</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Seleccioneu un sol objecte de posició per a obtindre l'orientació local.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Paràmetres</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Profunditat de l'arbre octal</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Divisions del solucionador</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Mostres per node</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Seleccioneu un sol punt del núvol</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Ha fallat la vista de triangulació.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_val-ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="val-ES" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Pla aproximat...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Aproxima un pla</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Superfície B-Spline aproximada...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Aproxima una superfície B-spline</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Superfície B-Spline aproximada...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation type="unfinished">Approximate surface...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Aproxima una superfície B-spline</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Reconstrucció de superfícies de Poisson</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Núvols de punts estructurats</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulació de núvols de punts estructurats</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Ajusta una superfície B-Spline</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Ajusta una superfície B-Spline</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>Direcció u</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Graus</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Punts de control</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>Direcció v</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Iteracions</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Factor de dimensió</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Suavitzat</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Pes total</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Longitud del degradat</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Energia de flexió</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Variació de la curvatura</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Direccions u/v definides per l'usuari</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Seleccioneu un sol objecte de posició per a obtindre l'orientació local.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Paràmetres</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Profunditat de l'arbre octal</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Divisions del sistema de resolució</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Mostres per node</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Selecció incorrecta</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Seleccioneu un sol punt del núvol</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Ha fallat la vista de triangulació.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Enginyeria inversa</translation>
    </message>
  </context>
</TS>
